from django.contrib.auth import authenticate, login, logout
from django.contrib.auth.forms import UserCreationForm
from django.shortcuts import render, redirect
from django.contrib.auth.decorators import login_required
from django.http import HttpResponse
from .models import Profile, mlModel, Billing, Interaction, Record
from .forms import UserLoginForm, UserUploadForm


# Registration view
def register_view(request):
    if request.method == 'POST':
        form = UserCreationForm(request.POST)
        if form.is_valid():
            user = form.save()
            # Create a profile for the user
            role = request.POST.get('role', 'user')  # Default to 'user' if not provided
            Profile.objects.create(user=user, role=role)
            return redirect('login')
    else:
        form = UserCreationForm()
    return render(request, 'register.html', {'form': form})

# Login view
def login_view(request):
    if request.method == 'POST':
        form = UserLoginForm(request.POST)
        if form.is_valid():
            username = form.cleaned_data['username']
            password = form.cleaned_data['password']
            user = authenticate(request, username=username, password=password)
            if user is not None:
                login(request, user)
                # Get the profile and role
                profile = user.profile
                role = profile.role
                # Redirect to the correct profile page based on the user's role
                if role == 'ai_engineer':
                    return redirect('ai_dashboard')
                elif role == 'finance':
                    return redirect('finance_dashboard')
                else:
                    return redirect('user_dashboard')
            else:
                # Handle invalid login
                return render(request, 'login.html', {'error': 'Invalid credentials'})
    else:
        form = UserLoginForm()
    return render(request, 'login.html', {'form': form})

def user_dashboard(request):
    return render(request, 'dashboards/user_dashboard.html')

def ai_dashboard(request):
    return render(request, 'dashboards/ai_dashboard.html')

def admin_dashboard(request):
    return render(request, 'dashboards/admin_dashboard.html')

def finance_dashboard(request):
    return render(request, 'dashboards/finance_dashboard.html')

def logout_view(request):
    logout(request)
    return redirect('home')  # Replace 'home' with the URL name for your homepage

# Profile view (only accessible if logged in)
@login_required
def profile_view(request):
    return render(request, 'profile.html', {'user': request.user})
